---
title: <span class="badge object-type-scalar"></span> PetabitsPerSecond
---
# <span class="badge object-type-scalar"></span> PetabitsPerSecond

Data rate: petabits/sec

## Definition

```python
# Data rate: petabits/sec
PetabitsPerSecond: typing.Literal["Pbits"] = "Pbits"
```
